@@ -4,14 +4,13 @@ from .s3_common import (
 from .s3_pomes import (
     s3_setup, s3_get_engines,
     s3_get_param, s3_get_params,
-    s3_assert_access, s3_startup,
-    s3_get_client, s3_get_version,
+    s3_startup, s3_get_client,
     s3_data_store, s3_data_retrieve,
     s3_file_store, s3_file_retrieve,
     s3_object_store, s3_object_retrieve,
     s3_item_exists, s3_item_get_info,
-    s3_item_get_tags, s3_item_remove,
-    s3_items_list, s3_items_remove
+    s3_item_get_tags, s3_item_remove, s3_items_remove,
+    s3_prefix_count, s3_prefix_list, s3_prefix_remove
 )
 
 __all__ = [
@@ -20,14 +19,13 @@ __all__ = [
     # s3_pomes
     "s3_setup", "s3_get_engines",
     "s3_get_param", "s3_get_params",
-    "s3_assert_access", "s3_startup",
-    "s3_get_client", "s3_get_version",
+    "s3_startup", "s3_get_client",
     "s3_data_store", "s3_data_retrieve",
     "s3_file_store", "s3_file_retrieve",
     "s3_object_store", "s3_object_retrieve",
     "s3_item_exists", "s3_item_get_info",
-    "s3_item_get_tags", "s3_item_remove",
-    "s3_items_list", "s3_items_remove"
+    "s3_item_get_tags", "s3_item_remove", "s3_items_remove",
+    "s3_prefix_count", "s3_prefix_list", "s3_prefix_remove"
 ]
 
 from importlib.metadata import version
